@@ -2,7 +2,7 @@
 # All rights reserved.
 #
 # See LICENSE file for full license.
-import collections
+import collections.abc
 import json
 import re
 import sys
@@ -12,7 +12,7 @@ import cfn_flip
 
 from . import validators
 
-__version__ = "3.0.1"
+__version__ = "3.1.0"
 
 # constants for DeletionPolicy and UpdateReplacePolicy
 Delete = "Delete"
@@ -36,6 +36,7 @@ MAX_PARAMETERS = 200
 MAX_RESOURCES = 500
 PARAMETER_TITLE_MAX = 255
 
+
 valid_names = re.compile(r"^[a-zA-Z0-9]+$")
 
 
@@ -287,7 +288,7 @@ class BaseAWSObject:
             value = kwargs[prop_name]
             is_aws_object = is_aws_object_subclass(prop_type)
             if is_aws_object:
-                if not isinstance(value, collections.Mapping):
+                if not isinstance(value, collections.abc.Mapping):
                     raise ValueError(
                         "Property definition for %s must be "
                         "a Mapping type" % prop_name
@@ -301,7 +302,7 @@ class BaseAWSObject:
                 for v in value:
                     new_v = v
                     if is_aws_object_subclass(prop_type[0]):
-                        if not isinstance(v, collections.Mapping):
+                        if not isinstance(v, collections.abc.Mapping):
                             raise ValueError(
                                 "Property definition for %s must be "
                                 "a list of Mapping types" % prop_name
@@ -594,6 +595,8 @@ class Tags(AWSHelperFn):
 
 
 class Template:
+    from troposphere.serverless import Globals
+
     props = {
         "AWSTemplateFormatVersion": (str, False),
         "Transform": (str, False),
@@ -601,6 +604,7 @@ class Template:
         "Parameters": (dict, False),
         "Mappings": (dict, False),
         "Resources": (dict, False),
+        "Globals": (Globals, False),
         "Outputs": (dict, False),
         "Rules": (dict, False),
     }
@@ -614,6 +618,7 @@ class Template:
         self.parameters = {}
         self.resources = {}
         self.rules = {}
+        self.globals = None
         self.version = None
         self.transform = None
 
@@ -693,8 +698,23 @@ class Template:
             self.version = "2010-09-09"
 
     def set_transform(self, transform):
+        from troposphere.serverless import SERVERLESS_TRANSFORM
+
+        if self.globals and transform != SERVERLESS_TRANSFORM:
+            raise ValueError(
+                "Cannot set transform to non-Serverless while using Globals"
+            )
         self.transform = transform
 
+    def set_globals(self, globals: Globals):
+        from troposphere.serverless import SERVERLESS_TRANSFORM
+
+        if self.transform != SERVERLESS_TRANSFORM:
+            raise ValueError(
+                f"Cannot set Globals for non-Serverless template (set transform to '{SERVERLESS_TRANSFORM}' first)"
+            )
+        self.globals = globals
+
     def to_dict(self):
         t = {}
         if self.description:
@@ -715,6 +735,8 @@ class Template:
             t["Transform"] = self.transform
         if self.rules:
             t["Rules"] = self.rules
+        if self.globals:
+            t["Globals"] = self.globals
         t["Resources"] = self.resources
 
         return encode_to_dict(t)
