@@ -7,6 +7,7 @@ import types
 
 from . import AWSHelperFn, AWSObject, AWSProperty
 from .apigateway import AccessLogSetting, CanarySetting, MethodSetting
+from .apigatewayv2 import AccessLogSettings, RouteSettings
 from .awslambda import (
     DestinationConfig,
     Environment,
@@ -20,6 +21,7 @@ from .awslambda import (
 from .dynamodb import ProvisionedThroughput, SSESpecification
 from .s3 import Filter
 from .validators import (
+    boolean,
     exactly_one,
     integer,
     integer_range,
@@ -37,6 +39,9 @@ except ImportError:
 assert types  # silence pyflakes
 
 
+SERVERLESS_TRANSFORM = "AWS::Serverless-2016-10-31"
+
+
 def primary_key_type_validator(x):
     valid_types = ["String", "Number", "Binary"]
     if x not in valid_types:
@@ -335,6 +340,10 @@ class EndpointConfiguration(AWSProperty):
             )
 
 
+class ApiDefinition(AWSProperty):
+    props = {"Bucket": (str, True), "Key": (str, True), "Version": (str, False)}
+
+
 class Api(AWSObject):
     resource_type = "AWS::Serverless::Api"
 
@@ -347,7 +356,7 @@ class Api(AWSObject):
         "CanarySetting": (CanarySetting, False),
         "Cors": ((str, Cors), False),
         "DefinitionBody": (dict, False),
-        "DefinitionUri": (str, False),
+        "DefinitionUri": ((str, ApiDefinition), False),
         "Domain": (Domain, False),
         "EndpointConfiguration": (EndpointConfiguration, False),
         "MethodSettings": ([MethodSetting], False),
@@ -367,6 +376,88 @@ class Api(AWSObject):
         mutually_exclusive(self.__class__.__name__, self.properties, conds)
 
 
+class OAuth2Authorizer(AWSProperty):
+    props = {
+        "AuthorizationScopes": (list, False),
+        "IdentitySource": (str, False),
+        "JwtConfiguration": (dict, False),
+    }
+
+
+class LambdaAuthorizationIdentity(AWSProperty):
+    props = {
+        "Context": (list, False),
+        "Headers": (list, False),
+        "QueryStrings": (list, False),
+        "ReauthorizeEvery": (integer, False),
+        "StageVariables": (list, False),
+    }
+
+
+class LambdaAuthorizer(AWSProperty):
+    props = {
+        "AuthorizerPayloadFormatVersion": (str, True),
+        "EnableSimpleResponses": (boolean, False),
+        "FunctionArn": (str, True),
+        "FunctionInvokeRole": (str, False),
+        "Identity": (LambdaAuthorizationIdentity, False),
+    }
+
+
+class HttpApiAuth(AWSProperty):
+    props = {
+        "Authorizers": ((OAuth2Authorizer, LambdaAuthorizer), False),
+        "DefaultAuthorizer": (str, False),
+    }
+
+
+class HttpApiCorsConfiguration(AWSProperty):
+    props = {
+        "AllowCredentials": (boolean, False),
+        "AllowHeaders": (list, False),
+        "AllowMethods": (list, False),
+        "AllowOrigins": (list, False),
+        "ExposeHeaders": (list, False),
+        "MaxAge": (integer, False),
+    }
+
+
+class HttpApiDefinition(ApiDefinition):
+    pass
+
+
+class HttpApiDomainConfiguration(Domain):
+    pass
+
+
+class HttpApi(AWSObject):
+    resource_type = "AWS::Serverless::HttpApi"
+
+    props = {
+        "AccessLogSettings": (AccessLogSettings, False),
+        "Auth": (HttpApiAuth, False),
+        "CorsConfiguration": ((str, HttpApiCorsConfiguration), False),
+        "DefaultRouteSettings": (RouteSettings, False),
+        "DefinitionBody": (dict, False),
+        "DefinitionUri": ((str, HttpApiDefinition), False),
+        "Description": (str, False),
+        "DisableExecuteApiEndpoint": (boolean, False),
+        "Domain": (HttpApiDomainConfiguration, False),
+        "FailOnWarnings": (boolean, False),
+        "RouteSettings": (dict, False),
+        "StageName": (str, False),
+        "StageVariables": (dict, False),
+        "Tags": (dict, False),
+    }
+
+    def validate(self):
+        conds = [
+            "DefinitionBody",
+            "DefinitionUri",
+        ]
+        mutually_exclusive(self.__class__.__name__, self.properties, conds)
+
+
 class PrimaryKey(AWSProperty):
     props = {"Name": (str, False), "Type": (primary_key_type_validator, False)}
 
@@ -527,3 +618,103 @@ class Application(AWSObject):
             "DefinitionUri",
         ]
         mutually_exclusive(self.__class__.__name__, self.properties, conds)
+
+
+class GlobalsHelperFn(AWSHelperFn):
+    def __init__(self, **kwargs):
+        remaining_kwargs = kwargs.copy()
+        for k, (key_type, required) in self.props.items():
+            if k in kwargs:
+                kwarg_value = remaining_kwargs.pop(k)
+                if not isinstance(kwarg_value, key_type):
+                    raise ValueError(
+                        f"Provided {self.__class__.__name__} property '{k}' is of type {type(kwarg_value)} instead of expected {key_type}"
+                    )
+            elif required:
+                raise ValueError(
+                    f"Required {self.__class__.__name__} property '{k}' not provided"
+                )
+
+        if remaining_kwargs:
+            unexpected_properties = [f"'{k}'" for k in remaining_kwargs.keys()]
+            raise ValueError(
+                f"Unexpected {self.__class__.__name__} properties provided: {unexpected_properties}"
+            )
+
+        self.data = kwargs
+
+
+class FunctionGlobals(GlobalsHelperFn):
+    props = {
+        "AssumeRolePolicyDocument": (policytypes, False),
+        "AutoPublishAlias": (str, False),
+        "CodeUri": ((S3Location, str), False),
+        "DeadLetterQueue": (DeadLetterQueue, False),
+        "DeploymentPreference": (DeploymentPreference, False),
+        "Description": (str, False),
+        "Environment": (Environment, False),
+        "EventInvokeConfig": (EventInvokeConfiguration, False),
+        "FileSystemConfigs": ([FileSystemConfig], False),
+        "Handler": (str, False),
+        "KmsKeyArn": (str, False),
+        "Layers": ([str], False),
+        "MemorySize": (validate_memory_size, False),
+        "PermissionsBoundary": (str, False),
+        "ProvisionedConcurrencyConfig": (ProvisionedConcurrencyConfiguration, False),
+        "ReservedConcurrentExecutions": (positive_integer, False),
+        "Runtime": (str, False),
+        "Tags": (dict, False),
+        "Timeout": (positive_integer, False),
+        "Tracing": (str, False),
+        "VpcConfig": (VPCConfig, False),
+    }
+
+
+class ApiGlobals(GlobalsHelperFn):
+    props = {
+        "AccessLogSetting": (AccessLogSetting, False),
+        "Auth": (Auth, False),
+        "BinaryMediaTypes": ([str], False),
+        "CacheClusterEnabled": (bool, False),
+        "CacheClusterSize": (str, False),
+        "CanarySetting": (CanarySetting, False),
+        "Cors": ((str, Cors), False),
+        "DefinitionUri": ((str, ApiDefinition), False),
+        "Domain": (Domain, False),
+        "EndpointConfiguration": (EndpointConfiguration, False),
+        "MethodSettings": ([MethodSetting], False),
+        "MinimumCompressionSize": (integer_range(0, 10485760), False),
+        "Name": (str, False),
+        "OpenApiVersion": (str, False),
+        "TracingEnabled": (bool, False),
+        "Variables": (dict, False),
+    }
+
+
+class HttpApiGlobals(GlobalsHelperFn):
+    props = {
+        "AccessLogSettings": (AccessLogSettings, False),
+        "Auth": (HttpApiAuth, False),
+        "StageVariables": (dict, False),
+        "Tags": (dict, False),
+    }
+
+
+class SimpleTableGlobals(GlobalsHelperFn):
+    props = {
+        "SSESpecification": (SSESpecification, False),
+    }
+
+
+class Globals(GlobalsHelperFn):
+    """Supported Globals properties.
+
+    See: https://docs.aws.amazon.com/serverless-application-model/latest/developerguide/sam-specification-template-anatomy-globals.html
+    """
+
+    props = {
+        "Api": (ApiGlobals, False),
+        "Function": (FunctionGlobals, False),
+        "HttpApi": (HttpApiGlobals, False),
+        "SimpleTable": (SimpleTableGlobals, False),
+    }
